@@ -211,7 +211,7 @@ class BaseOpenAI(BaseLLM, BaseModel):
             if not openai.proxy:
                 if values.get('proxy'):
                     openai.proxy = values['proxy']
-                    LOG.info("[tool]success use proxy: {}".format(values['proxy']))
+                    LOG.info("success use proxy: {}".format(values['proxy']))
                 else:
                     LOG.warning("proxy no find, directly request to openai instead")
 
@@ -604,7 +604,7 @@ class OpenAIChat(BaseLLM, BaseModel):
             if not openai.proxy:
                 if values.get('proxy'):
                     openai.proxy = values['proxy']
-                    LOG.info("[tool]success use proxy: {}".format(values['proxy']))
+                    LOG.info("success use proxy: {}".format(values['proxy']))
                 else:
                     LOG.warning("proxy no find, directly request to OpenAIChat instead")
 
